function expired_account_counters_now (widget) {
    "use strict";

    var model = openerp;
    var Qweb = openerp.web.qweb;

    widget.ExpiredAccountCountersNowWidget = widget.Base.extend({
        template: 'ExpiredAccountCountersNow',
        resPartner : [],
        moveLine : [],
        resCompany : [],
        resCompany :[],
        modelId:[],

        events: {
            'click a': 'showCustomers',
            'click h2': 'showCustomers',
        },
        init: function (parent) {
            this._super(parent, {
                width : 3,
                height: 2
            });
        },
        start: function () {
            var self = this;
            self.fetchInitial();
        },
        fetchInitial: function () {
            var self = this;
            self.$el.find('#morosidad').block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });
            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fetchPartner().then(function(resPartner){
                return resPartner;
            }).then(function(resPartner){
                self.resPartner = resPartner;
                return self.fetchMoveLine(resPartner);
            }).then(function(moveLine){
                self.moveLine= moveLine;
                return self.fetchResCompany();
            }).then(function(resCompany){
                self.resCompany=resCompany;
                return self.fetchResCurrecy(resCompany);
            }).then(function(resCurrecy){
                self.resCurrecy= resCurrecy;
                return self.fetchGetModelId();
            }).then(function(modelId){
                self.modelId = modelId;
                return self.fetchReduceMoveLine();
            });
        },
        // getModelId
        fetchGetModelId: function(){
            var self = this;
            var defer = $.Deferred();
            var irModelData = new model.web.Model('ir.model.data');
            var getObtjectReference = irModelData.get_func('get_object_reference');

            this.alive(getObtjectReference('account', 'invoice_form')).then(function(results){
                defer.resolve(results);
            });
            return defer;
        },
        // Partner
        fetchPartner: function () {
            var self = this;
            var defer = $.Deferred();
            var fields =['id', 'name', 'unreconciled_aml_ids', 'credit'];
            var domain =[['active', '=', true], ['credit', '>', 0]];
            var resPartner = new model.web.Model('res.partner');

            resPartner.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },
        // Move line
        fetchMoveLine: function (partner) {
            var self = this;
            var hoy =moment().format('YYYY-MM-DD');
            var defer = $.Deferred();
            var move_id = _.flatten(_.map(partner, function (map) {
                return map.unreconciled_aml_ids
            }));
            var field = ['id', 'partner_id', 'amount_residual', 'credit', 'debit', 'date_maturity', 'invoice','ref'];
            var domain = [['credit', '<=', 0], ['id', 'in', move_id], ['date_maturity', '=', hoy]];
            var moveLine = new model.web.Model('account.move.line');

            moveLine.query(field).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer;
        },
        //Comapnia
        fetchResCompany: function () {
            var self = this;
            var defer = $.Deferred();
            var fields =['id','name', 'currency_id','logo'];
            var domain =[['id', '=', 1]];
            var resComapy = new model.web.Model('res.company');

            resComapy.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer ;
        } ,
        // Res currecy
        fetchResCurrecy : function(company){
            var self = this;
            var defer = $.Deferred();

            var id_curency = _.flatten(_.map(company,function(map){
                return map.currency_id[0];
            }));

            var fields =['id','name', 'symbol'];
            var domain =[['id','in',id_curency]];
            var resCurrecy = new model.web.Model('res.currency');

            resCurrecy.query(fields).filter(domain).all().then(function(results){
                defer.resolve(results);
            });
            return defer;
        },
        // Reduce Move line
        fetchReduceMoveLine: function () {
            var self = this;
            var residual =0;
            var moneda =self.resCurrecy.shift();
            var company = _.map(self.resCompany, function(map){
                return map.currency_id[1];
            });

            if (self.moveLine.length > 0){
                residual = _.reduce(_.map(self.moveLine, function(map){
                    return map.amount_residual;
                }),function(memo, num){
                    return memo + num;
                });
            }

            if (moneda.id !=166){
                residual= accounting.formatNumber(residual,2, ".", ",");
            }else{
                residual= accounting.formatNumber(residual,",", ".");
            }

            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-content').find('a').text(residual).append(' <small>'+moneda.symbol+'</small>');
            // self.$el.find('.widget-footer').find('span').text("Monto en " + company);
            self.$el.find('#morosidad').unblock()
        },
        showCustomers: function (e) {
            var self = this;
            if (self.moveLine.length <= 0)
                return

            var moneda = self.resCurrecy.shift();
            var newmoveLine=[];
            newmoveLine = self.moveLine;
            var titleData=[
                {
                    title:"Deudas con vencimiento en el día de hoy"
                }
            ];
            var headerModal=[
                {
                    title:"id"
                },
                {
                    title:"Cliente"
                },
                {
                    title:"Numero de Factura"
                },
                {
                    title:"Vencimiento"
                },
                {
                    title:"Monto "
                }
            ];

            var modal = Qweb.render('ExpiredAccountCountersModal', {
                data : newmoveLine,
                dataThead : headerModal,
                modalTitle :titleData
            });

            $('.openerp_webclient_container').after(modal);
            $('.expired-account-modal').modal()
            $('.expired-account-modal').on('hidden.bs.modal', function (e) {
                self.removeModal(e);
            })

            var contenido = $('.expired-account-modal').find('.table-tbody');
            contenido.click(function (e) {
                $(contenido).find('tr').removeClass('table-row-select');
                $(e.target).closest('tr').addClass('table-row-select');
                var chirdren_id =$(e.target).closest('tr').children()[0].textContent;
                self.renderForm(chirdren_id);
            });
        },
        // Remover <Modal></Modal>
        removeModal: function (e) {
            $('.expired-account-modal').remove()
            $('.modal-backdrop').remove()
        },
        // Llamar form
        renderForm: function(id){
            var self= this;

            id = parseInt(id)

            // if (!id) return

            this.do_action({
                // name : "factura",
                type : "ir.actions.act_window",
                res_model : "account.invoice",
                views : [[self.modelId[1], 'form']],
                target : 'current',
                domain : [['id', '=', id]],
                context : {},
                res_id : id,
            }).then(function(){
                self.removeModal();
            });
        }
    });
}
